import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as React from "react";
import { animate, motion, useMotionValue, } from "framer-motion";
const pageStyle = {
    width: "100%",
    height: "100%",
    display: "inline-block",
    flex: "none",
};
const Slider = ({ x, i, onDragEnd, children }) => (_jsx(motion.div, { style: {
        ...pageStyle,
        x,
        left: `${i * 100}%`,
        right: `${i * 100}%`,
    }, drag: "x", dragElastic: 0.3, onDragEnd: onDragEnd, children: children }));
const dotWrapStyle = {
    position: "absolute",
    bottom: "10px",
    left: "50%",
    transform: "translateX(-50%)",
};
const dotItemStyle = {
    width: "20px",
    height: "20px",
    borderRadius: "50%",
    margin: "0 10px",
    display: "inline-block",
    cursor: "pointer",
};
const Dots = ({ length, activeIndex, setActiveIndex }) => {
    return (_jsx("div", { style: dotWrapStyle, children: new Array(length).fill("").map((_, i) => (_jsx("span", { onClick: () => setActiveIndex(i), style: {
                ...dotItemStyle,
                background: i === activeIndex ? "#000" : "#999",
                transform: `scale(${i === activeIndex ? 1.3 : 1})`,
            } }, i))) }));
};
const baseArrowStyle = {
    position: "absolute",
    width: "50px",
    height: "50px",
    backgroundColor: "rgba(0,0,0,0.5)",
    top: "50%",
    transform: "translateY(-50%)",
    borderRadius: "50%",
    color: "#fff",
    fontSize: "20px",
    display: "flex",
    alignItems: "center",
    justifyContent: "center",
    cursor: "pointer",
};
const Arrow = ({ left = false, children, onClick }) => (_jsx("div", { onClick: onClick, style: {
        ...baseArrowStyle,
        left: left ? "20px" : "initial",
        right: !left ? "10px" : "initial",
    }, children: children }));
const containerStyle = {
    position: "relative",
    width: "100%",
    height: "100%",
    overflowX: "hidden",
    display: "flex",
};
const transition = {
    type: "spring",
    bounce: 0,
};
const Contaier = React.forwardRef((props, ref) => (_jsx("div", { ref: ref, style: containerStyle, children: props.children })));
export const Carousel = ({ children, renderArrowLeft, renderArrowRight, renderDots, autoPlay = true, interval = 25000, loop = false, }) => {
    const x = useMotionValue(0);
    const containerRef = React.useRef(null);
    const [index, setIndex] = React.useState(0);
    const calculateNewX = () => -index * (containerRef.current?.clientWidth || 0);
    const handleEndDrag = (e, dragProps) => {
        const clientWidth = containerRef.current?.clientWidth || 0;
        const { offset } = dragProps;
        if (offset.x > clientWidth / 4) {
            handlePrev();
        }
        else if (offset.x < -clientWidth / 4) {
            handleNext();
        }
        else {
            animate(x, calculateNewX(), transition);
        }
    };
    const childrens = React.Children.toArray(children);
    const handleNext = () => {
        const idx = loop ? 0 : index;
        setIndex(index + 1 === childrens.length ? idx : index + 1);
    };
    const handlePrev = () => {
        const idx = loop ? childrens.length - 1 : 0;
        setIndex(index - 1 < 0 ? idx : index - 1);
    };
    React.useEffect(() => {
        const controls = animate(x, calculateNewX(), transition);
        return controls.stop;
    }, [index]);
    React.useEffect(() => {
        if (!autoPlay) {
            return;
        }
        const timer = setInterval(() => handleNext(), interval);
        return () => clearInterval(timer);
    }, [handleNext, interval]);
    return (_jsxs(Contaier, { ref: containerRef, children: [childrens.map((child, i) => (_jsx(Slider, { onDragEnd: handleEndDrag, x: x, i: i, children: child }, i))), renderArrowLeft ? (renderArrowLeft({ handlePrev, activeIndex: index })) : (_jsx(Arrow, { left: true, onClick: handlePrev, children: "\u2190" })), renderArrowRight ? (renderArrowRight({ handleNext, activeIndex: index })) : (_jsx(Arrow, { onClick: handleNext, children: "\u2192" })), renderDots ? (renderDots({ setActiveIndex: setIndex, activeIndex: index })) : (_jsx(Dots, { length: childrens.length, setActiveIndex: setIndex, activeIndex: index }))] }));
};
//# sourceMappingURL=Carousel.js.map