import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { useTouchable } from "./Hooks/touchable-hook";
import cx from "classnames";
import { safeBind } from "./Hooks/compose-bind";
/**
 * 旧版本 Touchable ，可注入ref的
 */
export const TouchRefComp = React.forwardRef(({ children, className = "", delay = 30, pressExpandPx, terminateOnScroll = false, component: Component = "button", onPress, disabled = false, ...other }, ref) => {
    const isLink = other.to || other.href;
    const { bind, hover, active } = useTouchable({
        onPress,
        disabled,
        delay,
        terminateOnScroll,
        pressExpandPx,
        behavior: isLink ? "link" : "button"
    });
    return (_jsx(Component, { className: cx("Touchable", className, {
            "Touchable--hover": hover,
            "Touchable--active": active
        }), ...safeBind({ ref }, bind, other), children: children }));
});
/**
 * 不注入ref的版本，优化性能
 */
export const Touchable = ({ children, className = "", delay = 30, pressExpandPx, terminateOnScroll = false, component: Component = "button", onPress, disabled = false, ...other }) => {
    const isLink = other.to || other.href;
    const { bind, hover, active } = useTouchable({
        onPress,
        disabled,
        delay,
        terminateOnScroll,
        pressExpandPx,
        behavior: isLink ? "link" : "button"
    });
    return (_jsx(Component, { className: cx("Touchable", className, {
            "Touchable--hover": hover,
            "Touchable--active": active
        }), ...safeBind(bind, other), children: children }));
};
//# sourceMappingURL=Touchable.js.map