import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { animate, motion, useMotionValue } from "framer-motion";
import { MoveFocusInside } from 'react-focus-lock';
import { useMMenuBarOcup } from "./MainMenuBar";
/**应该放在<TwoHalfFrame>的头上引入。 TwoHalfFrame下面右半边页面必须<TwoHalfRightPanel>包裹的。
 * 右半边详细操作页面被放大为整个视口的页面，放大
 * 跨越多层次的APP路由器页面。
 * */
export const PanelEnlargeCtx = React.createContext({
    enlarge: 2,
    setEnlarge: value => null,
    setActivecas: () => null,
    getActivecas: () => 1,
});
const containerStyle = {
    position: "relative",
    width: "100%",
    height: "100%",
    overflowX: "hidden",
    display: "inline-block",
    // display: "flex",
    flexDirection: 'row',
    justifyContent: 'space-between',
    flexWrap: 'nowrap',
};
const pageStyle = {
    top: 0,
    // display: "inline-block",
    flex: "none",
    overflowX: "hidden",
};
const transition = {
    type: "spring",
    bounce: 0,
};
const Contaier = React.forwardRef((props, ref) => (_jsx("div", { ref: ref, style: containerStyle, children: props.children })));
/**公用框架组件  Left左半列表摘要 + 右半边Console详细操作的页面。
 * TwoHalfFrame应该放在路由器每个路由顶部，外部加个PanelEnlargeCtx.Provider配套控制本实例TwoHalfFrame。
 * 本组件是框架，要配合 <TwoHalfRightPanel/>组件 以及<PanelEnlargeCtx.Provider 这两个东西来协同完成框架页面构建。
 * 需要在页面路由器头上加<PanelEnlargeCtx.Provider  value={{ enlarge, setEnlarge，activecas，setActivecas }}>
 * 【特别】<PanelEnlargeCtx.Provider的提供位置非常严格，可能无效:初始化取值，还是后来能修改赋值?。
 * */
export const TwoHalfFrame = React.forwardRef(({ children, rightPanel, leftStyle, rightStyle, ...other }, ref) => {
    const { barHeight, bottomCss, carousel, isBigSrc, mobileList } = useMMenuBarOcup(!rightPanel);
    const [enlarge, setEnlarge] = React.useState(2);
    const containerRef = React.useRef(null);
    const x = useMotionValue(0);
    //index和对外声称的左右边页面正好相反。
    const [index, setIndex] = React.useState(0);
    /*和布局相关的：手机书评模式情况下：transformX(0)实际是显示右半边页面的。transformX(containerRef.current?.clientWidth)实际是显示左半边页面的。
    * */
    const calculateNewX = () => (!carousel ? 0 : index === 1 ? 0 : -1) * (containerRef.current?.clientWidth || 0);
    const handleEndDrag = (e, dragProps) => {
        const clientWidth = containerRef.current?.clientWidth || 0;
        const { offset, velocity } = dragProps;
        const xDrag = Math.abs(velocity.x) >= Math.abs(velocity.y);
        if (!xDrag) {
            return animate(x, calculateNewX(), transition);
        }
        //向右边拉拽
        if (offset.x > clientWidth / 4) {
            handlePrev();
        }
        else if (offset.x < -clientWidth / 4) {
            handleNext();
        }
        else {
            animate(x, calculateNewX(), transition);
        }
    };
    //两个页面拼凑:
    const childrens = [children, rightPanel];
    const handleNext = () => {
        setIndex(index === 1 ? 0 : 1);
    };
    const handlePrev = () => {
        setIndex(index === 0 ? 1 : 0);
    };
    //外部也可以操纵，轮播台当前显示右边或左边。 【失败】注入Context实际有问题=导致ref.setActivecas()可能为undefined!
    // React.useImperativeHandle(ref, () => ({
    // }));
    const getActivecas = () => {
        return (index === 0 ? 1 : 0);
    };
    //无法直接用index对外替换Activecas？
    const setActivecas = (i) => {
        setIndex(i === 0 ? 1 : 0);
    };
    React.useEffect(() => {
        const controls = animate(x, calculateNewX(), transition);
        return controls.stop;
    }, [index]);
    //useLayoutEffect
    React.useEffect(() => {
        x.set(0);
        //若用x.set(0);在autofoucus导致自动切换显示右边页面情况，无法正常。只好改成默认set(-1*?)
        x.stop(); //这个必须加上！
        const controls = animate(x, calculateNewX(), transition);
        return controls.stop;
    }, [carousel, containerRef.current?.clientWidth, x]);
    //已经默认，不需要外边initActivecas注入
    React.useEffect(() => {
        //轮播台 右边页面=0，左边页面=1；
        setIndex(0);
    }, [rightPanel]);
    //非手机轮播台模式的左右两半边页面宽度比例： 左边没有=0，1：左边右边1比2， 2： 1比1， 3： 2比1， 4：右边没有。
    const leftpwp = enlarge === 0 ? 0 : (enlarge === 1 ? 33.4 : (enlarge === 4 ? 100 : (enlarge === 3 ? 66.6 : 50)));
    return (_jsx(PanelEnlargeCtx.Provider, { value: { enlarge, setEnlarge,
            setActivecas: setActivecas, getActivecas: getActivecas,
        }, children: _jsxs(Contaier, { ref: containerRef, ...other, children: [_jsx(MoveFocusInside, { children: _jsx(motion.div, { style: {
                            ...pageStyle,
                            x,
                            left: `0%`,
                            // right: `${0 * 100}%`,
                            // width: "100%",
                            // height: "100vh",
                        }, css: {
                            height: `calc(100vh - ${barHeight})`,
                            width: (carousel || mobileList) ? "100%" : `${leftpwp}%`,
                            overflowY: 'auto',
                            ...leftStyle,
                        }, drag: carousel ? "x" : false, dragElastic: 0.3, onDragEnd: handleEndDrag, children: childrens[0] }) }), _jsx(MoveFocusInside, { children: _jsx(motion.div, { style: {
                            ...pageStyle,
                            x,
                            // left: `${1 * 100}%`,
                            // right: `${1 * 100}%`,
                            // width: "100%",
                            // height: "100vh",
                        }, css: {
                            position: 'absolute',
                            left: carousel ? "100%" : mobileList ? '100%' : `${leftpwp}%`,
                            height: carousel ? `calc(100vh - ${barHeight})` : '100%',
                            width: carousel ? "100%" : mobileList ? '0%' : `${100 - leftpwp}%`,
                            ...rightStyle,
                        }, drag: carousel ? "x" : false, dragElastic: 0.3, onDragEnd: handleEndDrag, children: childrens[1] }) })] }) }));
});
//# sourceMappingURL=TwoHalfFrame.js.map